import React from 'react';
import { Col, Typography, Row, Select, Button } from 'antd';
import commonStyles from '@/styles/common.module.less';
import { useIntl } from 'umi';
import { Empty } from '@/components/Empty/Empty';
import { ProTable } from '@ant-design/pro-table';
import { useMemoizedFn } from 'ahooks';
import styles from '../../styles.module.less';

const dummyTopProducts = [
  {
    id: 1,
    product: 'Tomato',
    factory: 'American International Tomato Company',
    category: 'Fruits',
    salesAmount: '100,000',
  },
  {
    id: 2,
    product: 'Potato',
    factory: 'American International Potato Company',
    category: 'Not Vegetable',
    salesAmount: '100,000',
  },
  {
    id: 3,
    product: 'Rice',
    factory: 'American International Grains Company',
    category: 'Grass',
    salesAmount: '100,000',
  },
];

export default () => {
  const intl = useIntl();

  const getTopProducts = useMemoizedFn(async () => {
    return {
      success: true,
      data: dummyTopProducts,
      total: dummyTopProducts.length,
    };
  });

  const topProductsColumns = [
    {
      title: intl.formatMessage({ id: 'analytics.product' }),
      dataIndex: 'product',
    },
    {
      title: intl.formatMessage({ id: 'analytics.factory' }),
      dataIndex: 'factory',
    },
    {
      title: intl.formatMessage({ id: 'analytics.category' }),
      dataIndex: 'category',
    },
    {
      title: intl.formatMessage({ id: 'analytics.salesAmount' }),
      dataIndex: 'salesAmount',
    },
  ];

  return (
    <Col span={24}>
      <Row justify={'space-between'}>
        <Col>
          <Typography.Title
            style={{ display: 'inline-block' }}
            className={commonStyles.sectionTitle}
            level={4}
          >
            {intl.formatMessage({ id: 'analytics.topProducts' })}
          </Typography.Title>
          <Select style={{ marginLeft: '10px', width: '150px' }} defaultValue={'monthly'}>
            <Select.Option key={'monthly'}>
              {intl.formatMessage({ id: 'analytics.monthly' })}
            </Select.Option>
          </Select>
        </Col>
        <Col>
          <Button type={'link'}>{intl.formatMessage({ id: 'analytics.more' })}</Button>
        </Col>
      </Row>
      <ProTable
        className={styles.table}
        rowKey={'id'}
        search={false}
        toolBarRender={false}
        // @ts-ignore
        request={getTopProducts}
        columns={topProductsColumns}
        locale={{
          emptyText: (
            <Empty
              style={{ margin: '20px 0' }}
              text={intl.formatMessage({ id: 'dashboard.noTasks' })}
            />
          ),
        }}
      />
    </Col>
  );
};
